package edu.nyu.scps.binder;

import android.app.Service;
import android.content.Intent;
import android.media.MediaPlayer;
import android.net.Uri;
import android.os.Binder;
import android.os.IBinder;
import android.widget.Toast;

import java.io.IOException;

public class MediaPlayerService extends Service {
    private MediaPlayer mediaPlayer;
    private float volume; //0.0f is minimum, 1.0f is maximum
    private MediaPlayerBinder mediaPlayerBinder = new MediaPlayerBinder();

    public MediaPlayerService() {
    }

    @Override
    public void onCreate() {
        super.onCreate();
        mediaPlayer = new MediaPlayer();
        Uri uri = Uri.parse("android.resource://" + getPackageName() + "/" + R.raw.musette);
        try {
            mediaPlayer.setDataSource(this, uri);
        } catch (IOException iOException) {
            Toast toast = Toast.makeText(MediaPlayerService.this, iOException.toString(), Toast.LENGTH_LONG);
            toast.show();
        }
        mediaPlayer.prepareAsync(); //will eventually call the onPrepared method of the OnPreparedListener

        mediaPlayer.setOnCompletionListener(new MediaPlayer.OnCompletionListener() {
            @Override
            public void onCompletion(MediaPlayer mediaPlayer) {
                MediaPlayerService.this.stopSelf();  //calls onDestroy, below
            }
        });
    }

    //called by the startService method of the Activity

    @Override
    public int onStartCommand(Intent intent, int flags, int startId) {
        mediaPlayer.setOnPreparedListener(new MediaPlayer.OnPreparedListener() {
            @Override
            public void onPrepared(MediaPlayer mp) {
                setVolume(0.5f);
                mp.start();
            }
        });

        return super.onStartCommand(intent, flags, startId);
    }

    //getter and setter

    public float getVolume() {
        return volume;
    }

    public void setVolume(float volume) {
        if (mediaPlayer != null) {
            this.volume = volume;
            mediaPlayer.setVolume(volume, volume);  //left, right
        }
    }

    //called by stopSelf

    @Override
    public void onDestroy() {
        if (mediaPlayer != null) {
            mediaPlayer.release();
            mediaPlayer = null;
        }
        super.onDestroy();
    }

    public class MediaPlayerBinder extends Binder {
        MediaPlayerService getService() {
            return MediaPlayerService.this;
        }
    }

    //called by the bindService method of an Activity.

    @Override
    public IBinder onBind(Intent intent) {
        //Return the communication channel to the service.
        return mediaPlayerBinder;
    }
}
